==> sflphone_1.3.0.orig.tar.gz: sflphone-1.3.0/kde/src/lib/visitors/presenceserializationvisitor.h <==
/****************************************************************************
 *   Copyright (C) 2013-2014 by Savoir-Faire Linux                         ***
 *   Author : Emmanuel Lepage Vallee <emmanuel.lepage@savoirfairelinux.com> *
 *                                                                          *
 *   This library is free software; you can redistribute it and/or          *
 *   modify it under the terms of the GNU Lesser General Public             *
 *   License as published by the Free Software Foundation; either           *
 *   version 2.1 of the License, or (at your option) any later version.     *
 *                                                                          *
 *   This library is distributed in the hope that it will be useful,        *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of         *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU      *
 *   Lesser General Public License for more details.                        *
 *                                                                          *
 *   You should have received a copy of the GNU General Public License      *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.  *
 ***************************************************************************/
#ifndef PRESENCESERIALIZATIONVISITOR_H
#define PRESENCESERIALIZATIONVISITOR_H

#include "../typedefs.h"

class AbstractBookmarkModel;

class LIB_EXPORT PresenceSerializationVisitor {
public:
   virtual void     serialize() = 0;
   virtual void     load     () = 0;
   virtual ~PresenceSerializationVisitor(){};
};

#endif //PRESENCESERIALIZATIONVISITOR_H

==> sflphone_1.4.1.orig.tar.gz: sflphone-1.4.1/kde/src/lib/visitors/presenceserializationvisitor.h <==
/****************************************************************************
 *   Copyright (C) 2013-2014 by Savoir-Faire Linux                         ***
 *   Author : Emmanuel Lepage Vallee <emmanuel.lepage@savoirfairelinux.com> *
 *                                                                          *
 *   This library is free software; you can redistribute it and/or          *
 *   modify it under the terms of the GNU Lesser General Public             *
 *   License as published by the Free Software Foundation; either           *
 *   version 2.1 of the License, or (at your option) any later version.     *
 *                                                                          *
 *   This library is distributed in the hope that it will be useful,        *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of         *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU      *
 *   Lesser General Public License for more details.                        *
 *                                                                          *
 *   You should have received a copy of the GNU General Public License      *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.  *
 ***************************************************************************/
#ifndef PRESENCESERIALIZATIONVISITOR_H
#define PRESENCESERIALIZATIONVISITOR_H

#include "../typedefs.h"

class AbstractBookmarkModel;
class AbstractItemBackendBase;

class LIB_EXPORT PresenceSerializationVisitor {
public:
   virtual void serialize() = 0;
   virtual void load     () = 0;
   virtual bool isTracked(AbstractItemBackendBase* backend) = 0;
   virtual void setTracked(AbstractItemBackendBase* backend, bool tracked) = 0;
   virtual ~PresenceSerializationVisitor(){};
};

#endif //PRESENCESERIALIZATIONVISITOR_H
